@@ -118,7 +118,13 @@ MaxPoint AutoSearchCrossValidationDriver::doCrossValidationLoop(
                                                           predLogLikelihood);
 
 	            double stdDevEstimate = computeStDev(predLogLikelihood, pointEstimate);
-
+/*
+	            std::cout << "predLikelihoods: ";
+	            for (auto x : predLogLikelihood) {
+	            	std::cout << x << " ";
+	            }
+	            std::cout << "\n";
+*/
 	            std::ostringstream stream;
 	            stream << "AvgPred = " << pointEstimate << " with stdev = " << stdDevEstimate << std::endl;
 	            searcher.tried(currentOptimal[dim], pointEstimate, stdDevEstimate);
